@@ -2,6 +2,7 @@
 from argparse import ArgumentParser
 
 from jamd import jamd_viewer
+from jamd.jamd_viewer import Styles
 
 
 def parse_arguments():
@@ -13,7 +14,7 @@ def parse_arguments():
 
 def main():
     arguments = parse_arguments()
-    jamd_viewer.run(arguments.path)
+    jamd_viewer.run(arguments.path, style=Styles.GITHUB)
 
 
 if __name__ == '__main__':
